@@ -89,7 +89,7 @@ class Sentry(object):
       `wrap_wsgi=False`.
     - Capture information from Flask-Login (if available).
     """
-    # TODO(dcramer): the client isnt using local context and therefore
+    # TODO(dcramer): the client isn't using local context and therefore
     # gets shared by every app that does init on it
     def __init__(self, app=None, client=None, client_cls=Client, dsn=None,
                  logging=False, level=logging.NOTSET, wrap_wsgi=True,
@@ -207,11 +207,17 @@ class Sentry(object):
     def captureException(self, *args, **kwargs):
         assert self.client, 'captureException called before application configured'
         result = self.client.captureException(*args, **kwargs)
-        self.last_event_id = self.client.get_ident(result)
+        if result:
+            self.last_event_id = self.client.get_ident(result)
+        else:
+            self.last_event_id = None
         return result
 
     def captureMessage(self, *args, **kwargs):
         assert self.client, 'captureMessage called before application configured'
         result = self.client.captureMessage(*args, **kwargs)
-        self.last_event_id = self.client.get_ident(result)
+        if result:
+            self.last_event_id = self.client.get_ident(result)
+        else:
+            self.last_event_id = None
         return result
