@@ -187,7 +187,7 @@ class ClientTest(TestCase):
                 'Content-Type': 'application/octet-stream',
                 'X-Sentry-Auth': (
                     'Sentry sentry_timestamp=1328055286.51, '
-                    'sentry_client=raven-python/%s, sentry_version=4, '
+                    'sentry_client=raven-python/%s, sentry_version=5, '
                     'sentry_key=public, '
                     'sentry_secret=secret' % (raven.VERSION,))
             },
@@ -216,6 +216,35 @@ class ClientTest(TestCase):
             },
         )
 
+    @mock.patch('raven.transport.http.HTTPTransport.send')
+    @mock.patch('raven.base.ClientState.should_try')
+    def test_raise_exception_on_send_error(self, should_try, _send_remote):
+        should_try.return_value = True
+        client = Client(
+            servers=['sync+http://example.com'],
+            public_key='public',
+            secret_key='secret',
+            project=1,
+        )
+
+        # Test for the default behaviour in which a send error is handled by the client
+        _send_remote.side_effect = Exception()
+        client.capture('Message', data={}, date=None, time_spent=10,
+                       extra={}, stack=None, tags=None, message='Test message')
+        assert client.state.status == client.state.ERROR
+
+        # Test for the case in which a send error is raised to the calling frame.
+        client = Client(
+            servers=['sync+http://example.com'],
+            public_key='public',
+            secret_key='secret',
+            project=1,
+            raise_send_errors=True,
+        )
+        with self.assertRaises(Exception):
+            client.capture('Message', data={}, date=None, time_spent=10,
+                           extra={}, stack=None, tags=None, message='Test message')
+
     def test_encode_decode(self):
         data = {'foo': 'bar'}
         encoded = self.client.encode(data)
@@ -291,12 +320,12 @@ class ClientTest(TestCase):
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
         self.assertEquals(event['message'], 'ValueError: foo')
-        self.assertTrue('sentry.interfaces.Exception' in event)
-        exc = event['sentry.interfaces.Exception']
+        self.assertTrue('exception' in event)
+        exc = event['exception']['values'][0]
         self.assertEquals(exc['type'], 'ValueError')
         self.assertEquals(exc['value'], 'foo')
         self.assertEquals(exc['module'], ValueError.__module__)  # this differs in some Python versions
-        assert 'sentry.interfaces.Stacktrace' not in event
+        assert 'stacktrace' not in event
         stacktrace = exc['stacktrace']
         self.assertEquals(len(stacktrace['frames']), 1)
         frame = stacktrace['frames'][0]
@@ -329,7 +358,7 @@ class ClientTest(TestCase):
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
         self.assertEquals(event['message'], 'DecoratorTestException')
-        exc = event['sentry.interfaces.Exception']
+        exc = event['exception']['values'][0]
         self.assertEquals(exc['type'], 'DecoratorTestException')
         self.assertEquals(exc['module'], self.DecoratorTestException.__module__)
         stacktrace = exc['stacktrace']
@@ -357,7 +386,7 @@ class ClientTest(TestCase):
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
         self.assertEquals(event['message'], 'test')
-        self.assertFalse('sentry.interfaces.Stacktrace' in event)
+        assert 'stacktrace' not in event
         self.assertTrue('timestamp' in event)
 
     def test_context(self):
@@ -386,9 +415,9 @@ class ClientTest(TestCase):
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
         self.assertEquals(event['message'], 'test')
-        self.assertTrue('sentry.interfaces.Stacktrace' in event)
-        self.assertEquals(len(frames), len(event['sentry.interfaces.Stacktrace']['frames']))
-        for frame, frame_i in zip(frames, event['sentry.interfaces.Stacktrace']['frames']):
+        assert 'stacktrace' in event
+        self.assertEquals(len(frames), len(event['stacktrace']['frames']))
+        for frame, frame_i in zip(frames, event['stacktrace']['frames']):
             self.assertEquals(frame[0].f_code.co_filename, frame_i['abs_path'])
             self.assertEquals(frame[0].f_code.co_name, frame_i['function'])
 
@@ -398,7 +427,7 @@ class ClientTest(TestCase):
         self.assertEquals(len(self.client.events), 1)
         event = self.client.events.pop(0)
         self.assertEquals(event['message'], 'test')
-        self.assertTrue('sentry.interfaces.Stacktrace' in event)
+        self.assertTrue('stacktrace' in event)
         self.assertTrue('timestamp' in event)
 
     def test_site(self):
