@@ -106,8 +106,8 @@ class FlaskTest(BaseTest):
 
         event = self.raven.events.pop(0)
 
-        self.assertTrue('sentry.interfaces.Exception' in event)
-        exc = event['sentry.interfaces.Exception']
+        assert 'exception' in event
+        exc = event['exception']['values'][0]
         self.assertEquals(exc['type'], 'ValueError')
         self.assertEquals(exc['value'], 'hello world')
         self.assertEquals(event['level'], logging.ERROR)
@@ -121,8 +121,8 @@ class FlaskTest(BaseTest):
 
         event = self.raven.events.pop(0)
 
-        self.assertTrue('sentry.interfaces.Http' in event)
-        http = event['sentry.interfaces.Http']
+        assert 'request' in event
+        http = event['request']
         self.assertEquals(http['url'], 'http://localhost/an-error/')
         self.assertEquals(http['query_string'], 'foo=bar')
         self.assertEquals(http['method'], 'GET')
@@ -148,8 +148,8 @@ class FlaskTest(BaseTest):
 
         event = self.raven.events.pop(0)
 
-        self.assertTrue('sentry.interfaces.Http' in event)
-        http = event['sentry.interfaces.Http']
+        assert 'request' in event
+        http = event['request']
         self.assertEquals(http['url'], 'http://localhost/an-error/')
         self.assertEquals(http['query_string'], 'biz=baz')
         self.assertEquals(http['method'], 'POST')
@@ -177,8 +177,8 @@ class FlaskTest(BaseTest):
         self.assertEquals(event['event_id'], response.headers['X-Sentry-ID'])
 
         assert event['message'] == 'ValueError: Boom'
-        assert 'sentry.interfaces.Http' in event
-        assert 'sentry.interfaces.Exception' in event
+        assert 'request' in event
+        assert 'exception' in event
 
     def test_captureMessage_captures_http(self):
         response = self.client.get('/message/?foo=bar')
@@ -188,8 +188,8 @@ class FlaskTest(BaseTest):
         event = self.raven.events.pop(0)
         self.assertEquals(event['event_id'], response.headers['X-Sentry-ID'])
 
-        self.assertTrue('sentry.interfaces.Message' in event)
-        self.assertTrue('sentry.interfaces.Http' in event)
+        assert 'sentry.interfaces.Message' in event
+        assert 'request' in event
 
     @patch('flask.wrappers.RequestBase._load_form_data')
     def test_get_data_handles_disconnected_client(self, lfd):
@@ -199,8 +199,8 @@ class FlaskTest(BaseTest):
 
         event = self.raven.events.pop(0)
 
-        self.assertTrue('sentry.interfaces.Http' in event)
-        http = event['sentry.interfaces.Http']
+        assert 'request' in event
+        http = event['request']
         self.assertEqual({}, http.get('data'))
 
     def test_error_handler_with_ignored_exception(self):
@@ -249,5 +249,5 @@ class FlaskLoginTest(BaseTest):
         self.client.get('/an-error-logged-in/')
         event = self.raven.events.pop(0)
         assert event['message'] == 'ValueError: hello world'
-        assert 'sentry.interfaces.Http' in event
-        assert 'sentry.interfaces.User' in event
+        assert 'request' in event
+        assert 'user' in event
